DISTRO=""
VER=""

function GetInitSys {
  # known distros
  case $DISTRO in
    centos)
      case $VER in
        6)
          echo sysvinit
          return
        ;;
      esac
    ;;
    redhat)
      if [[ $VER == 6* ]] ; then
        echo sysvinit
        return
      fi
    ;;
    sles)
      if [[ $VER == 11\.* ]] ; then
        echo sysvinit
        return
      fi
      if [[ $VER == 12\.* ]] ; then
        echo systemd
        return
      fi
    ;;
  esac
  # generic case
  for initsys in systemd upstart sysvinit; do
    case $DISTRO in
      ubuntu | debian | raspbian)
        dpkg -S /sbin/init | grep -i $initsys &> /dev/null
        [ $? -eq 0 ] && break
        ;;
      centos | redhat)
        yum whatprovides -q /sbin/init | head -1 | grep -i $initsys &> /dev/null
        [ $? -eq 0 ] && break
        ;;
      sles)
        zypper wp /sbin/init | grep -i $initsys &> /dev/null
        [ $? -eq 0 ] && break
        ;;
      *)
        ;;
    esac
  done
  echo $initsys
}

function GetLnxBase {
  case $DISTRO in
    ubuntu | debian | raspbian)
      lnxBase="deb"
      ;;
    centos | redhat | sles)
      lnxBase="lsb"
      ;;
    *)
      ;;
  esac
  echo $lnxBase
}

# start/stop/restart service
# OpService initsys [start|stop|restart]
function OpService {
  case $1 in
  systemd)
    systemctl $2 azsecd.service || echo "Failed to $2 azsecd"
  ;;
  upstart | sysvinit)
    service azsecd $2 || echo "Failed to $2 azsecd"
  ;;
  esac
}

# stop service and kill service process (if present)
# StopService initsys <process name>
function StopService {
  OpService $1 stop
  found=$false
  pids=$(pgrep -u root $2 2> /dev/null) || echo "No such process"
  if [ ! -z $pids ]; then
    found=$true
    for pid in $pids; do
      kill -SIGKILL $pid
    done
  fi
  #double-check there are no processes
  if [ $found ]; then
    pids=$(pgrep -u root $2 2> /dev/null) || echo "No such process"
    if [ ! -z $pids ]; then
      echo "Failed to kill $2"
      return 1
    fi
  fi
}

# determine distro and version
if [ -e /etc/system-release-cpe ]; then
  DISTRO=`awk -F":" '{print $3}' /etc/system-release-cpe`
  VER=`awk -F":" '{print $5}' /etc/system-release-cpe`
elif [ -e /etc/os-release ]; then
  DISTRO=`grep "^ID=" /etc/os-release | awk -F"=" '{print $2}' | sed 's/"//g'`
  VER=`grep "^VERSION_ID=" /etc/os-release | awk -F"=" '{print $2}' | sed 's/"//g'`
fi
